#INCLUDE "box.ch"
#INCLUDE "directry.ch"
#INCLUDE "common.ch"
#INCLUDE "inkey.ch"

static aLevel := {}, nLevel, nHandle

static aMastDir := {}, cGlobMastDir, nMastDirLen

*!*****************************************************************************
*!
*!       Function: DIR_COMP()
*!
*!*****************************************************************************
function dir_comp( cMastDir, cDrive, cTreeFile )

local cParentDir, nParent, nCurrentRec, cThisPath
local CRLF := chr( 13 ) + chr( 10 )

field path, NAME, size, FDAT, FTIM, ATTR, PARENT


DEFAULT cMastDir to ''
default cDrive to 'C:'
default cTreeFile to 'DIR_COMP.TXT'

begin sequence

if empty( cMastDir )
   qout( 'Usage:' )
   qout( '' )
   qout( 'DIR_COMP <Master Dir> <Drive:[\path]> [<outfilename>]' )
   qout( '' )
   qout( '   Where' )
   qout( '' )
   qout( '      <Master Dir> is the directory to compare to' )
   qout( '      <Drive:[\path]> is the tree root to compare with ' )
   qout( '      [<outfilename>] is the output (defaults to DIR_COMP.TXT)' )
   qout( '' )
   qout( 'Example:' )
   qout( '' )
   qout( 'DIR_COMP F:\MASTER F:\ F_COMPAR.OUT' )
   qout( '' )
   qout( '' )
   qout( '' )
   qout( '' )
   break
endif

cDrive := upper( cDrive )
cTreeFile := upper( cTreeFile )

setcolor( 'G+/B' )
clear screen

@ 3, 15 say 'Compare single Directory to all other Directories'

dispbox(  5, 5, 22, 75, B_SINGLE + ' ' )
setcolor( 'GR+/B' )

dbcreate('files.dbf',{ { 'PATH', 'C', 40, 0 },;
                       { 'NAME', 'C', 12, 0 },;
                       { 'SIZE', 'N', 10, 0 },;
                       { 'FDAT', 'D',  8, 0 },;
                       { 'FTIM', 'C',  8, 0 },;
                       { 'ATTR', 'C',  4, 0 } } )

show( 'Gathering file names from master directory' )

cMastDir := upper( cMastDir )

if right( cMastDir, 1 ) == '\'
   cMastDir := left( cMastDir, len( cMastDir ) - 1 )
endif

aMastDir := directory( cMastDir + '\' )

nMastDirLen := len( aMastDir )

if nMastDirLen < 1
   show( 'No files in master directory: ' + cMastDir )
   break
endif

use files

SHOW( 'Scanning Directories on ' + cDrive )

cGlobMastdir := cMastDir

DIR_RECURS( cDrive )

index on path + name to files

go top

nHandle := fcreate( cTreeFile, 0 )
cThisPath := files->path

fwrite( nHandle, CRLF + cThisPath + CRLF + CRLF )

do while files->( !eof() )
   fwrite( nHandle, files->name + CRLF )
   files->( dbskip( 1 ) )
   if cThisPath <> files->path
      cThisPath := files->path
      fwrite( nHandle, CRLF + cThisPath + CRLF + CRLF )
   endif
enddo
fclose( nHandle )

end sequence

dbcloseall()

devpos( 22, 0 )

return NIL

*!*****************************************************************************
*!
*!      Procedure: DIR_RECURS
*!
*!      Called by: TREE()             (function  in TREE.PRG)
*!               : DIR_RECURS         (procedure in TREE.PRG)
*!
*!          Calls: DIR_RECURS         (procedure in TREE.PRG)
*!
*!*****************************************************************************
static function DIR_RECURS( cPath )

local x, y, nPointer, lShowedIt
local aFiles   := directory( cPath + '\*.*', 'D' )
local nFilCount := len( aFiles )

for x := 1 to nFilCount
   if inkey() == K_ESC
      break
   endif
   lShowedIt := .f.
   if 'D' $ aFiles[ X, F_ATTR ]
      if aFiles[ X, F_NAME ] <> '.'
         DIR_RECURS( cPath + '\' + aFiles[ X, F_NAME ] )
      endif
   else
      if aFiles[ X, F_NAME ] <> '..'
         for y := 1 to nMastDirLen
            if aMastDir[ y, F_NAME ] == aFiles[ x, F_NAME ]
               files->( dbappend() )
               FILES->PATH := cPath
               FILES->NAME := aFiles[ X, F_NAME ]
               FILES->SIZE := aFiles[ X, F_SIZE ]
               FILES->FDAT := aFiles[ X, F_DATE ]
               FILES->FTIM := aFiles[ X, F_TIME ]
               FILES->ATTR := aFiles[ X, F_ATTR ]
               lShowedIt := .t.
               SHOW( '* ' + cPath + '\' + aFiles[ X, 1 ] )
            endif
         next
      endif
   endif
   if !lShowedIt
      SHOW( '  ' + cPath + '\' + aFiles[ X, 1 ] )
   endif
next

return NIL

*!*****************************************************************************
*!
*!      Procedure: SHOW1
*!
*!*****************************************************************************
static function SHOW( text )

scroll( 6, 6, 21, 74, 1 )

@ 21, 6 say text

return NIL

*: EOF: TREE.PRG
